@@ -10,7 +10,7 @@ class DebugToolbarTests(unittest.TestCase):
     def setUp(self):
         self.config = testing.setUp()
         self.config.registry.settings['mako.directories'] = []
-        from pyramid.mako_templating import renderer_factory
+        from .. import renderer_factory
         self.config.add_renderer('.dbtmako', renderer_factory)
 
     def tearDown(self):
@@ -143,7 +143,7 @@ class Test_toolbar_handler(unittest.TestCase):
         self.config.add_route(ROOT_ROUTE_NAME, '/_debug_toolbar')
         self.config.add_static_view('_debugtoolbar/static',
                                     STATIC_PATH)
-        from pyramid.mako_templating import renderer_factory
+        from .. import renderer_factory
         self.config.add_renderer('.dbtmako', renderer_factory)
 
     def tearDown(self):
