@@ -6,6 +6,7 @@ from pyramid.interfaces import Interface
 from pyramid.renderers import render
 from pyramid.threadlocal import get_current_request
 from pyramid.response import Response
+from pyramid.exceptions import URLDecodeError
 from pyramid_debugtoolbar.tbtools import get_traceback
 from pyramid_debugtoolbar.compat import url_unquote
 from pyramid_debugtoolbar.compat import bytes_
@@ -17,6 +18,7 @@ from pyramid_debugtoolbar.utils import ROOT_ROUTE_NAME
 from pyramid_debugtoolbar.utils import EXC_ROUTE_NAME
 from pyramid_debugtoolbar.utils import logger
 from pyramid_debugtoolbar.utils import addr_in
+from pyramid_debugtoolbar.utils import last_proxy
 from pyramid.httpexceptions import WSGIHTTPException
 
 
@@ -92,8 +94,11 @@ def beforerender_subscriber(event):
             panel.process_beforerender(event)
 
 
-def toolbar_tween_factory(handler, registry):
+def toolbar_tween_factory(handler, registry, _logger=None):
     """ Pyramid tween factory for the debug toolbar """
+    # _logger passed for testing purposes only
+    if _logger is None:
+        _logger = logger
     settings = registry.settings
 
     if not get_setting(settings, 'enabled'):
@@ -103,6 +108,7 @@ def toolbar_tween_factory(handler, registry):
     panel_classes = get_setting(settings, 'panels', [])
     intercept_exc = get_setting(settings, 'intercept_exc')
     intercept_redirects = get_setting(settings, 'intercept_redirects')
+    show_on_exc_only = get_setting(settings, 'show_on_exc_only')
     hosts = get_setting(settings, 'hosts')
     auth_check = registry.queryUtility(IRequestAuthorization)
     exclude_prefixes = get_setting(settings, 'exclude_prefixes', [])
@@ -117,11 +123,16 @@ def toolbar_tween_factory(handler, registry):
         exclude = [root_path] + exclude_prefixes
         request.exc_history = exc_history
         last_proxy_addr = None
-        starts_with_excluded = list(filter(None, map(request.path.startswith,
-                                                     exclude)))
+
+        try:
+            p = request.path
+        except UnicodeDecodeError as e:
+            raise URLDecodeError(e.encoding, e.object, e.start, e.end, e.reason)
+        
+        starts_with_excluded = list(filter(None, map(p.startswith, exclude)))
 
         if request.remote_addr:
-            last_proxy_addr = request.remote_addr.split(',').pop().strip()
+            last_proxy_addr = last_proxy(request.remote_addr)
 
         if last_proxy_addr is None \
             or starts_with_excluded \
@@ -156,10 +167,10 @@ def toolbar_tween_factory(handler, registry):
                 msg = 'Exception at %s\ntraceback url: %s'
                 exc_url = request.route_url(EXC_ROUTE_NAME, _query=qs)
                 exc_msg = msg % (request.url, exc_url)
-                logger.exception(exc_msg)
+                _logger.exception(exc_msg)
                 return response
             else:
-                logger.exception('Exception at %s' % request.url)
+                _logger.exception('Exception at %s' % request.url)
             raise
 
         else:
@@ -181,7 +192,8 @@ def toolbar_tween_factory(handler, registry):
                         response.app_iter = [content]
                         response.status_int = 200
 
-            toolbar.process_response(response)
+            if not show_on_exc_only:
+                toolbar.process_response(response)
             return response
 
         finally:
